/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import _ from 'lodash';

import logged, {setToken} from '../config/logged';
import { Card } from '../classes/Card';
import { errorRequestTreatment } from '../global/errors';

const getMyCardDeckRequest = () => {
    return logged.get('/card/myDeck')
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let object  = data.object;
            let token   = _.get(headers, 'x-token');

            if (!_.isEmpty(object, true)) {
                let deck = [];

                object.map(card => deck.push(new Card(card)));

                setToken(token);

                return {
                    result  : 'GET_DECK_CARDS_SUCCESS',
                    deck    : deck,
                    message : message,
                    token   : token
                }
            }

            else return {
                result  : 'GET_DECK_CARDS_FAIL',
                deck    : null,
                message : message === null ? 'Deck vazio!' : message,
                token   : token
            }
        })
        .catch(error => { return errorRequestTreatment(error, 'GET_DECK_CARDS') });
};

export function getMyDeck() {
    return getMyCardDeckRequest()
        .then(async (res) => {
            let result = {};

            if (res.result === 'GET_DECK_CARDS_SUCCESS') {
                result = {
                    message  : res.message,
                    deck     : res.deck,
                    newToken : res.token
                }
            }
            else if (res.result === 'GET_DECK_CARDS_FAIL') {
                result = {
                    message  : res.message,
                    deck     : null,
                    newToken : res.token
                }
            }

            return result
        });
}

module.exports = {
    getMyDeck
};
