/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import _ from 'lodash';

import logged, { setToken } from '../config/logged';
import { errorRequestTreatment } from '../global/errors';
import { Extract } from '../classes/Extract';

const getExtractsRequest = () => {
    let currentMonth = new Date().getMonth() + 1;
    let currentYear  = new Date().getFullYear();

    return logged.get('job/extract/' + currentYear + '/' + currentMonth)
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let object  = data.object;
            let token   = _.get(headers, 'x-token');

            if (!_.isEmpty(object, true)) {
                let extracts = [];

                object.map(extract => {
                    extracts.push(new Extract(extract))
                });

                setToken(token);

                return {
                    result   : 'GET_EXTRACTS_SUCCESS',
                    extracts : extracts,
                    message  : message,
                    token    : token
                }
            }

            else return {
                result   : 'GET_EXTRACTS_FAIL',
                extracts : null,
                message  : message === null ? 'Você não possui mais atividades!' : message,
                token    : token
            }
        })
        .catch(error => { return errorRequestTreatment(error, 'GET_EXTRACTS') });
};

export function getExtracts() {
    return getExtractsRequest()
        .then(async (res) => {
            let result = {};

            if (res.result === 'GET_EXTRACTS_SUCCESS') {
                result = {
                    message  : res.message,
                    extracts : res.extracts,
                    newToken : res.token
                }
            }
            else if (res.result === 'GET_EXTRACTS_FAIL') {
                result = {
                    message  : res.message,
                    extracts : null,
                    newToken : res.token
                }
            }

            return result
        });
}

module.exports = {
    getExtracts
};
