/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import _ from 'lodash';

import logged, { setToken } from '../config/logged';
import { errorRequestTreatment } from '../global/errors';
import { Task } from '../classes/Task';
import {Extract} from "../classes/Extract";

const getTasksRequest = () => {
    return logged.get('/job/thisWeek')
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let object  = data.object;
            let token   = _.get(headers, 'x-token');

            if (!_.isEmpty(object, true)) {
                let tasks;
                let toDo       = [];
                let inProgress = [];
                let done       = [];

                object.map(activity => {
                    switch (activity.status) {
                        case 'WAITING':
                            let toDoTask = new Task(activity.task);
                            toDoTask.duration = activity.hours;
                            toDoTask.expectedAt = activity.date;
                            toDo.push(toDoTask);
                            break;

                        case 'EXECUTING':
                            let inProgressTask = new Task(activity.task);
                            inProgressTask.duration = activity.hours;
                            inProgressTask.expectedAt = activity.date;
                            inProgress.push(inProgressTask);
                            break;

                        case 'DONE':
                            let doneTask = new Task(activity.task);
                            doneTask.duration = activity.hours;
                            doneTask.expectedAt = activity.date;
                            done.push(doneTask);
                            break;
                    }
                });

                tasks = {
                    toDo       : toDo,
                    inProgress : inProgress,
                    done       : done
                };

                setToken(token);

                return {
                    result   : 'GET_TASKS_SUCCESS',
                    tasks    : tasks,
                    message  : message,
                    token    : token
                }
            }

            else return {
                result   : 'GET_TASKS_FAIL',
                tasks    : null,
                message  : message === null ? 'Você não possui mais atividades!' : message,
                token    : token
            }
        })
        .catch(error => { return errorRequestTreatment(error, 'GET_TASKS') });
};

const makeActionTaskRequest = (id: number, action: string, reason: string) => {
    let url;
    if (action === 'finalize') url = '';
    else url = '?reason=' + reason;
    return logged.get('/task/' + id + '/' + action + url)
        .then(res => {
            let headers = res.headers;
            let data    = res.data;
            let message = data.message;
            let object  = data.object;
            let token   = _.get(headers, 'x-token');

            if (!_.isEmpty(object, true)) {

                setToken(token);

                return {
                    result  : 'SUCCESS',
                    object  : object,
                    message : message,
                    token   : token
                }
            }

            else return {
                result  : 'FAIL',
                object  : {},
                message : message === null ? 'Você não possui mais atividades!' : message,
                token   : token
            }
        })
        .catch(error => { return errorRequestTreatment(error, '') });
};

export function checkOutTask(id: number) {
    return makeActionTaskRequest(id, 'finalize', null)
        .then(async (res) => {
            let result = {};

            if (res.result === 'SUCCESS') {
                result = {
                    message   : res.message,
                    taskId    : res.object.id,
                    taskName  : res.object.name,
                    finalized : res.object.finalizedAt,
                    newToken  : res.token
                }
            }

            else if (res.result === 'FAIL') {
                result = {
                    message   : res.message,
                    taskId    : null,
                    taskName  : null,
                    finalized : null,
                    newToken  : res.token
                }
            }

            return result
        });
}

export function suspendTask(id: number, reason: string) {
    return makeActionTaskRequest(id, 'suspend', reason)
        .then(async (res) => {
            let result = {};

            if (res.result === 'SUCCESS') {
                result = {
                    message   : res.message,
                    taskId    : res.object.id,
                    taskName  : res.object.name,
                    newToken  : res.token
                }
            }

            else if (res.result === 'FAIL') {
                result = {
                    message   : res.message,
                    taskId    : null,
                    taskName  : null,
                    newToken  : res.token
                }
            }

            return result
        });
}

export function giveBackTask(id: number, reason: string) {
    return makeActionTaskRequest(id, 'giveBack', reason)
        .then(async (res) => {
            let result = {};

            if (res.result === 'SUCCESS') {
                result = {
                    message   : res.message,
                    taskId    : res.object.id,
                    taskName  : res.object.name,
                    newToken  : res.token
                }
            }

            else if (res.result === 'FAIL') {
                result = {
                    message   : res.message,
                    taskId    : null,
                    taskName  : null,
                    newToken  : res.token
                }
            }

            return result
        });
}

export function getTasks() {
    return getTasksRequest()
        .then(async (res) => {
            let result = {};

            if (res.result === 'GET_TASKS_SUCCESS') {
                result = {
                    message  : res.message,
                    tasks    : res.tasks,
                    newToken : res.token
                }
            }
            else if (res.result === 'GET_TASKS_FAIL') {
                result = {
                    message  : res.message,
                    tasks    : null,
                    newToken : res.token
                }
            }

            return result
        });
}

module.exports = {
    getTasks,
    checkOutTask,
    suspendTask,
    giveBackTask
};
